%define abi     0.10
%define libname %mklibname %{name} %{abi}
%define devname %mklibname %{name} -d

Name:           mgba
Version:        0.10.3
Release:        %mkrel 1
Summary:        Fast and accurate Game Boy Advance emulator
Group:          Emulators
License:        MPLv2.0
URL:            https://mgba.io
Source0:        https://github.com/mgba-emu/mgba/archive/%{version}/%{name}-%{version}.tar.gz
Patch1:         mgba-0.9.3-unbundle-inih.patch
# fix for bundled rapidjson (P11->P16)
# https://github.com/Tencent/rapidjson/pull/719
Patch11:        0001-Removed-non-compiling-assignment-operator.-Fixed-718.patch
# https://github.com/Tencent/rapidjson/pull/719
Patch12:        0002-Explicitly-disable-copy-assignment-operator.patch
# https://github.com/Tencent/rapidjson/pull/1137
Patch13:        0003-Three-way-comparison-for-CLang-10-fix-1679.patch
# https://github.com/Tencent/rapidjson/pull/1679
Patch14:        0004-Fix-recursive-operator-call-in-C-20-1846.patch
# https://github.com/Tencent/rapidjson/pull/1847
Patch15:        0005-gate-definition-of-symmetric-equality-operators-on-i.patch
# https://github.com/Tencent/rapidjson/pull/2091
Patch16:        0006-do-not-define-operator-in-C-20.patch

BuildRequires:  cmake
BuildRequires:  ffmpeg-devel
# TODO: Unbundled lzma.
#BuildRequires:  lzma-devel
BuildRequires:  cmake(Qt5Core)
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5Help)
BuildRequires:  cmake(Qt5Multimedia)
BuildRequires:  cmake(Qt5OpenGL)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  pkgconfig(epoxy)
BuildRequires:  pkgconfig(inih)
BuildRequires:  pkgconfig(libedit)
BuildRequires:  pkgconfig(libzip)
BuildRequires:  pkgconfig(MagickWand)
BuildRequires:  pkgconfig(minizip)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(sqlite3)

Recommends:     %{name}-qt

%description
mGBA is an emulator for running Game Boy Advance games. It aims to be
faster and more accurate than many existing Game Boy Advance emulators,
as well as adding features that other emulators lack. It also supports
Game Boy and Game Boy Color games.

This package contains the command-line SDL 2 frontend for mGBA; the
"%{name}-qt" package contains a full-featured graphical Qt 5 frontend.

%package qt
Summary:        Qt frontend for the mGBA emulator
Group:          Emulators

%description qt
This package contains the Qt frontend of the mGBA emulator. The
lighter weight command-line SDL 2 frontend is provided by the "%{name}"
package.

%package -n %{libname}
Summary:        Shared data and library used by mGBA's Qt and SDL frontends
Group:          System/Libraries

%description -n %{libname}
This package contains the mGBA library and data files used by both the
Qt and SDL frontends of the mGBA emulator.

%package -n %{devname}
Summary:        Development files for libmgba
Group:          Development/C
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{devname}
Development files for libmgba, the library for the mGBA emulator.

%prep
%autosetup -p1

# Unbundle thirdparty libs
rm -rf src/third-party/{inih,libpng,sqlite3,zlib}

%build
# FIXME:
# Workaround GCC 14 build error
export CFLAGS="%{optflags} -Wno-incompatible-pointer-types"
%cmake
%cmake_build

%install
%cmake_install

%files
%doc CHANGES README.md
%license LICENSE
%{_bindir}/%{name}
%{_mandir}/man6/%{name}.6*

%files qt
%doc CHANGES README.md
%license LICENSE
%{_bindir}/%{name}-qt
%{_datadir}/%{name}/
%{_datadir}/applications/io.mgba.mGBA.desktop
%{_iconsdir}/hicolor/*/apps/io.mgba.mGBA.png
%{_mandir}/man6/%{name}-qt.6*

%files -n %{libname}
%{_libdir}/lib%{name}.so.%{abi}
%{_libdir}/lib%{name}.so.%{version}

%files -n %{devname}
%doc %{_docdir}/mGBA/
%{_libdir}/lib%{name}.so
%{_includedir}/%{name}/
%{_includedir}/%{name}-util/


%changelog
* Thu May 16 2024 daviddavid <daviddavid> 0.10.3-1.mga10
+ Revision: 2064435
- new version: 0.10.3
- add patches from cauldron/rapidjson to fix bundled rapidjson build

* Tue Mar 15 2022 mrambo3501 <mrambo3501> 0.9.3-2.mga9
+ Revision: 1793272
- rebuild for ffmpeg 5.0

* Tue Jan 11 2022 akien <akien> 0.9.3-1.mga9
+ Revision: 1767956
- Version 0.9.3
- Add -devel package, could be used by dolphin-emu

* Wed Jun 02 2021 akien <akien> 0.9.1-1.mga9
+ Revision: 1729392
- Version 0.9.1

* Sat Feb 27 2021 neoclust <neoclust> 0.8.4-2.mga9
+ Revision: 1692953
- Rebuild against new imagemagick

* Sun Jan 17 2021 akien <akien> 0.8.4-1.mga8
+ Revision: 1672252
- Version 0.8.4

* Thu Dec 17 2020 umeabot <umeabot> 0.8.3-3.mga8
+ Revision: 1659057
- Rebuild for new Qt5

* Wed Oct 21 2020 akien <akien> 0.8.3-2.mga8
+ Revision: 1637810
- Fix packaging of Qt-specific data dir, add obsoletes to ease upgrade

* Wed Oct 21 2020 akien <akien> 0.8.3-1.mga8
+ Revision: 1637667
- Version 0.8.3

* Tue Feb 18 2020 umeabot <umeabot> 0.6.3-7.mga8
+ Revision: 1541587
- Mageia 8 Mass Rebuild

* Mon Dec 30 2019 kekepower <kekepower> 0.6.3-6.mga8
+ Revision: 1474981
- Use new cmake macros
- Rebuild for new imagemagick

* Sun Mar 31 2019 umeabot <umeabot> 0.6.3-5.mga7
+ Revision: 1383378
- Qt5 Rebuild

* Sun Sep 23 2018 umeabot <umeabot> 0.6.3-4.mga7
+ Revision: 1299529
- Mageia 7 Mass Rebuild

* Sat Jun 02 2018 daviddavid <daviddavid> 0.6.3-3.mga7
+ Revision: 1233603
- add patch to fix build with new Qt5 >= 5.11.0 stack

* Wed May 02 2018 kekepower <kekepower> 0.6.3-2.mga7
+ Revision: 1224489
- Rebuild for ImageMagic 7.0.7.29

* Sun Apr 29 2018 daviddavid <daviddavid> 0.6.3-1.mga7
+ Revision: 1223591
- new version: 0.6.3

* Thu Jan 18 2018 shlomif <shlomif> 0.6.0-3.mga7
+ Revision: 1194417
- Rebuild for new imagemagick

* Sat Dec 30 2017 wally <wally> 0.6.0-2.mga7
+ Revision: 1187971
- rebuild for new libzip

* Sun Jul 23 2017 akien <akien> 0.6.0-1.mga7
+ Revision: 1129655
- imported package mgba

